Hi!

While working on the PR92883 patch I've noticed some typos, fixed thusly,
bootstrapped/regtested on x86_64-linux and i686-linux, committed to trunk as
obvious.

2019-12-10  Jakub Jelinek  <ja...@redhat.com>

        * ipa-param-manipulation.c
        (ipa_param_body_adjustments::register_replacement): Fix comment typo
        - accross -> across.
        * ipa-sra.c (propagate_used_across_scc_edge, ipa_sra_analysis):
        Likewise.
        (param_splitting_across_edge): Fix typo in dump message - accross
        -> across.

--- gcc/ipa-param-manipulation.c.jj     2019-10-01 18:16:10.756161489 +0200
+++ gcc/ipa-param-manipulation.c        2019-12-10 13:27:31.050486852 +0100
@@ -895,7 +895,7 @@ ipa_param_adjustments::debug ()
 }
 
 /* Register that REPLACEMENT should replace parameter described in APM and
-   optionally as DUMMY to mark transitive splits accross calls.  */
+   optionally as DUMMY to mark transitive splits across calls.  */
 
 void
 ipa_param_body_adjustments::register_replacement (ipa_adjusted_param *apm,
--- gcc/ipa-sra.c.jj    2019-11-25 11:33:41.019082342 +0100
+++ gcc/ipa-sra.c       2019-12-10 13:27:16.792705175 +0100
@@ -3167,7 +3167,7 @@ isra_mark_caller_param_used (isra_func_s
 
 
 /* Propagate information that any parameter is not used only locally within a
-   SCC accross CS to the caller, which must be in the same SCC as the
+   SCC across CS to the caller, which must be in the same SCC as the
    callee. Push any callers that need to be re-processed to STACK.  */
 
 static void
@@ -3397,7 +3397,7 @@ param_splitting_across_edge (cgraph_edge
        : 0);
 
   if (dump_file && (dump_flags & TDF_DETAILS))
-    fprintf (dump_file, "Splitting accross %s->%s:\n",
+    fprintf (dump_file, "Splitting across %s->%s:\n",
             cs->caller->dump_name (), callee->dump_name ());
 
   unsigned i;
@@ -3876,9 +3876,9 @@ ipa_sra_analysis (void)
              param_removal_cross_scc_edge (cs);
        }
 
-      /* Look at edges within the current SCC and propagate used-ness accross
-          them, pushing onto the stack all notes which might need to be
-          revisited.  */
+      /* Look at edges within the current SCC and propagate used-ness across
+        them, pushing onto the stack all notes which might need to be
+        revisited.  */
       FOR_EACH_VEC_ELT (cycle_nodes, j, v)
        v->call_for_symbol_thunks_and_aliases (propagate_used_to_scc_callers,
                                               &stack, true);

        Jakub

Reply via email to